@@ -1,57 +1,57 @@
 #' Create traditional dummy variables
 #'
 #' `step_dummy()` creates a *specification* of a recipe step that will convert
-#' nominal data (e.g. characters or factors) into one or more numeric binary
-#' model terms corresponding to the levels of the original data.
+#' nominal data (e.g. factors) into one or more numeric binary model terms
+#' corresponding to the levels of the original data.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
-#' @param ... One or more selector functions to choose variables
-#'  for this step. See [selections()] for more details. The selected
-#'  variables _must_ be factors.
+#' @param ... One or more selector functions to choose variables for this step.
+#'   See [selections()] for more details. The selected variables _must_ be
+#'   factors.
 #' @param one_hot A logical. For C levels, should C dummy variables be created
-#' rather than C-1?
-#' @param preserve Use `keep_original_cols` to specify whether the selected
-#'  column(s) should be retained (in addition to the new dummy variables).
-#' @param naming A function that defines the naming convention for
-#'  new dummy columns. See Details below.
-#' @param levels A list that contains the information needed to
-#'  create dummy variables for each variable contained in
-#'  `terms`. This is `NULL` until the step is trained by
-#'  [prep()].
+#'   rather than C-1?
+#' @param preserve This argument has been deprecated. Please use
+#'   `keep_original_cols` instead.
+#' @param naming A function that defines the naming convention for new dummy
+#'   columns. See Details below.
+#' @param levels A list that contains the information needed to create dummy
+#'   variables for each variable contained in `terms`. This is `NULL` until the
+#'   step is trained by [prep()].
 #' @template step-return
 #' @family dummy variable and encoding steps
 #' @seealso [dummy_names()]
 #' @export
-#' @details `step_dummy()` will create a set of binary dummy
-#'  variables from a factor variable. For example, if an unordered
-#'  factor column in the data set has levels of "red", "green",
-#'  "blue", the dummy variable bake will create two additional
-#'  columns of 0/1 data for two of those three values (and remove
-#'  the original column). For ordered factors, polynomial contrasts
-#'  are used to encode the numeric values.
+#' @details
 #'
-#' By default, the excluded dummy variable (i.e. the reference
-#'  cell) will correspond to the first level of the unordered
-#'  factor being converted.
+#' `step_dummy()` will create a set of binary dummy variables from a factor
+#' variable. For example, if an unordered factor column in the data set has
+#' levels of "red", "green", "blue", the dummy variable bake will create two
+#' additional columns of 0/1 data for two of those three values (and remove the
+#' original column). For ordered factors, polynomial contrasts are used to
+#' encode the numeric values.
+#'
+#' By default, the excluded dummy variable (i.e. the reference cell) will
+#' correspond to the first level of the unordered factor being converted.
+#' `step_relevel()` can be used to create a new reference level by setting the
+#' `ref_level` argument.
 #'
 #' @template dummy-naming
 #'
 #' @details
 #'
-#' To change the type of contrast being used, change the global
-#' contrast option via `options`.
+#' To change the type of contrast being used, change the global contrast option
+#' via `options`.
 #'
-#' When the factor being converted has a missing value, all of the
-#'  corresponding dummy variables are also missing. See [step_unknown()] for
-#'  a solution.
+#' When the factor being converted has a missing value, all of the corresponding
+#' dummy variables are also missing. See [step_unknown()] for a solution.
 #'
-#' When data to be processed contains novel levels (i.e., not
-#' contained in the training set), a missing value is assigned to
-#' the results. See [step_other()] for an alternative.
+#' When data to be processed contains novel levels (i.e., not contained in the
+#' training set), a missing value is assigned to the results. See [step_other()]
+#' for an alternative.
 #'
-#' If no columns are selected (perhaps due to an earlier `step_zv()`),
-#'  [bake()] will return the data as-is (e.g. with no dummy variables).
+#' If no columns are selected (perhaps due to an earlier `step_zv()`), [bake()]
+#' will return the data as-is (e.g. with no dummy variables).
 #'
 #' Note that, by default, the new dummy variable column names obey the naming
 #' rules for columns. If there are levels such as "0", [dummy_names()] will put
@@ -65,11 +65,16 @@
 #' The [package vignette for dummy variables](https://recipes.tidymodels.org/articles/Dummies.html)
 #' and interactions has more information.
 #'
-#'  # Tidying
+#' # Tidying
 #'
-#'  When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#'  `terms` (the selectors or original variables selected) and `columns`
-#'  (the list of corresponding binary columns) is returned.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `columns` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{columns}{character, names of resulting columns}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -166,11 +171,9 @@ step_dummy_new <-
 #' @export
 prep.step_dummy <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
-  check_type(training[, col_names], types = c("string", "factor", "ordered"))
+  check_type(training[, col_names], types = c("factor", "ordered"))
 
   if (length(col_names) > 0) {
-    col_names <- check_factor_vars(training, col_names, "step_dummy")
-
     ## I hate doing this but currently we are going to have
     ## to save the terms object from the original (= training)
     ## data
@@ -216,42 +219,14 @@ prep.step_dummy <- function(x, training, info = NULL, ...) {
   )
 }
 
-check_factor_vars <- function(data, col_names, step_name, call = caller_env()) {
-  fac_check <- vapply(data[, col_names], is.factor, logical(1))
-  if (any(!fac_check)) {
-    rlang::warn(
-      paste0(
-        "The following variables are not factor vectors and will be ignored: ",
-        paste0("`", names(fac_check)[!fac_check], "`", collapse = ", ")
-      )
-    )
-  }
-  col_names <- col_names[fac_check]
-  if (length(col_names) == 0) {
-    rlang::abort(
-      paste0(
-        "The `terms` argument in `",
-        step_name,
-        "` did not select ",
-        "any factor columns."
-      ),
-      call = call
-    )
-  }
-  col_names
-}
-
 warn_new_levels <- function(dat, lvl, details = NULL) {
   ind <- which(!(dat %in% lvl))
   if (length(ind) > 0) {
     lvl2 <- unique(dat[ind])
-    rlang::warn(
-      paste0(
-        "There are new levels in a factor: ",
-        paste0(lvl2, collapse = ", "),
-        details
-      )
-    )
+    cli::cli_warn(c(
+      "!" = "There are new levels in a factor: {.var {lvl2}}.",
+      details
+    ))
   }
   invisible(NULL)
 }
@@ -280,14 +255,12 @@ bake.step_dummy <- function(object, new_data, ...) {
     is_ordered <- attr(levels, "dataClasses") == "ordered"
 
     if (is.null(levels_values)) {
-      rlang::abort("Factor level values not recorded")
+      cli::cli_abort("Factor level values not recorded in {.var col_name}.")
     }
 
     if (length(levels_values) == 1) {
-      rlang::abort(
-        paste0(
-          "Only one factor level in ", col_name, ": ", levels_values
-        )
+      cli::cli_abort(
+        "Only one factor level in {.var col_name}: {levels_values}."
       )
     }
 
@@ -354,7 +327,8 @@ get_dummy_columns <- function(x, one_hot) {
 tidy.step_dummy <- function(x, ...) {
   if (is_trained(x)) {
     if (length(x$levels) > 0) {
-      res <- purrr::map_dfr(x$levels, get_dummy_columns, x$one_hot, .id = "terms")
+      res <- purrr::map(x$levels, get_dummy_columns, x$one_hot)
+      res <- purrr::list_rbind(res, names_to = "terms")
     } else {
       res <- tibble(terms = character(), columns = character())
     }
