@@ -1,4 +1,4 @@
-#' Logarithmic Transformation
+#' Logarithmic transformation
 #'
 #' `step_log()` creates a *specification* of a recipe step that will log
 #' transform data.
@@ -18,8 +18,14 @@
 #'
 #' # Tidying
 #'
-#' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
-#' `terms` (the columns that will be affected) and `base`.
+#' When you [`tidy()`][tidy.recipe()] this step, a tibble is returned with
+#' columns `terms`, `base` , and `id`:
+#'
+#' \describe{
+#'   \item{terms}{character, the selectors or variables selected}
+#'   \item{base}{numeric, value for the base}
+#'   \item{id}{character, id of this step}
+#' }
 #'
 #' @template case-weights-not-supported
 #'
@@ -118,7 +124,8 @@ prep.step_log <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_log <- function(object, new_data, ...) {
-  col_names <- names(object$columns)
+  # For backward compatibility #1284
+  col_names <- names(object$columns) %||% object$columns
   check_new_data(col_names, object, new_data)
 
   # for backward compat
@@ -127,7 +134,7 @@ bake.step_log <- function(object, new_data, ...) {
   }
 
   if (object$signed && object$offset != 0) {
-    rlang::warn("When signed is TRUE, offset will be ignored")
+    cli::cli_warn("When {.arg signed} is TRUE, {.arg offset} will be ignored.")
   }
 
   for (col_name in col_names) {
